#ifndef _FUNC_H
#define _FUNC_H

#define COM1	0
#define COM2	1
#define COM3	2
#define COM4	3

#define BAUDR_110	0
#define BAUDR_300	1
#define BAUDR_600	2
#define BAUDR_1200	3
#define BAUDR_2400	4
#define BAUDR_4800	5
#define BAUDR_9600	6
#define BAUDR_14400	7
#define BAUDR_19200	8
#define BAUDR_38400	9
#define BAUDR_56000	10
#define BAUDR_57600	11
#define BAUDR_115200	12

#define DBIT_4		0
#define DBIT_5		1
#define DBIT_6		2
#define DBIT_7		3
#define DBIT_8		4

#define PARIT_NONE	0
#define PARIT_EVEN	1
#define PARIT_ODD	2
#define PARIT_MARK	3
#define PARIT_SPACE	4

#define STOPBITS_ONE	0
#define STOPBITS_ONE5	1
#define STOPBITS_TWO	2

//Command define
#define CMD_SelectCard				0x01
#define CMD_LoginToSector			0x02
#define CMD_ReadDataBlock			0x03
#define CMD_WriteDataBlock			0x04
#define CMD_ReadValueBlock			0x05
#define CMD_WriteValueBlock			0x06
#define CMD_WriteMasterKey			0x07

#define CMD_IncrementValue			0x08
#define CMD_DecrementValue			0x09
#define CMD_CopyValue				0x0A
#define CMD_Halt				0x0B
#define CMD_ContinuousRead			0x0C
#define CMD_RequestMifareCard		0x0D	//2002.12.05 add
#define CMD_AutoLogin				0x0E	//2002.12.05 add

//#define CMD_ReadEEPROM				0x10	//2002.12.05 add
//#define CMD_WriteEEPROM				0x11	//2002.12.05 add
#define CMD_LoginWithKeyStored		0x12	//2002.12.05 add
#define CMD_StoreKey				0x13	//2002.12.05 add

#define CMD_GetATS				0x20
#define CMD_Deselect				0x21
#define CMD_ExchangeAPDU			0x22

#define CMD_SmartCardPowerUp			0x30
#define CMD_SmartCardPowerDown			0x31
#define CMD_SmartCardExchangeAPDU		0x32

#define CMD_IOOutput				0x40
#define CMD_WriteToGPIO				0x40	//2002.12.05 modify ,Write to GPIO
#define CMD_ReadFromGPIO			0x41	//2002.12.05 modify ,Read from GPIO
#define CMD_ChangeBaudRate			0x42	//2002.12.05 add

#define CMD_EnterISP				0xA0
#define CMD_ByteProgram				0xA1
#define CMD_ChipProtect				0xA2
#define CMD_PageErase				0xA3
#define CMD_ChipErase				0xA4
#define CMD_ByteVerify				0xA5

#define CMD_Reset				0xFF
//----------------------------------------------------------------------------------------------

//Event define
#define EVENT_CHECKSUM_ERROR			0xFD //հУʹ
#define EVENT_UNKNOWN_ERROR			0xFE
//----------------------------------------------------------------------------------------------

//Status define
#define STATUS_OperationSuccess			0x00
#define STATUS_NoTag				0x01
#define STATUS_LoginSuccess			0x02
#define STATUS_LoginFail			0x03
#define STATUS_ReadFail				0x04
#define STATUS_WriteFail			0x05
#define STATUS_UnableReadAfterWrite		0x06
#define STATUS_ReadAfterWriteError		0x07
#define STATUS_ResetFail			0x08
#define STATUS_HaltFail				0x09
#define STATUS_CollisionOccur           0x0A
#define STATUS_NoSAK                    0x0B
#define STATUS_LoadKeyFail              0x0C
#define STATUS_NotAuthenticate          0x0D
#define STATUS_NotAValueBlock           0x0E
#define STATUS_UnableToHalt             0x0F

#define STATUS_AccessDenied             0x10
#define STATUS_InvalidATS               0x11
#define STATUS_EEPROMAccessError		0x12	//2002.12.05 add
#define STATUS_KeySlotNumberOutOfRange	0x13	//2002.12.05 add
#define STATUS_EEPROMDataOutOfRange		0x14	//2002.12.05 add

#define STATUS_SectorOutOfRange         0x20
#define STATUS_InvalidKeyType           0x21
#define STATUS_BlockOutOfRange          0x22
#define STATUS_BaudRateOutOfRange		0x23	//2002.12.05 add

#define STATUS_NoSmartCard		0x2B

#define STATUS_ProgramError             0x30
#define STATUS_VerifyError              0x31

#define STATUS_ChecksumError		0xF0
#define STATUS_InvalidCommand		0xF1
#define STATUS_CommunicationLineError   0xF2
#define STATUS_UnknownError             0xF3

#define LED_Red				0xFE
#define LED_Green			0xFD
#define LED_RedAndGreen			0xFC	

//----------------------------------------------------------------------------------------------
#ifdef __cplusplus
extern "C" {
#endif

/* basic function phototype */
BOOL WINAPI Connection(HWND hWnd,int wMsg);
void WINAPI Disconnection(void);

BOOL WINAPI SetCOM(int ComPortIdx);
BOOL WINAPI SetBaud(int BaudIdx);
BOOL WINAPI SetDataBits(int DataBitsIdx);
BOOL WINAPI SetParity(int ParityIdx);
BOOL WINAPI SetStopBits(int StopBitsIdx);

bool WINAPI HYMIFARE_ReadData(int Addr,int DataNum);
bool WINAPI HYMIFARE_WriteData(int Addr,BYTE *DataBuf,int DataNum);

//Select Mifare card
bool WINAPI HYMIFARE_SelectCard(void);

//Login to a sector
bool WINAPI HYMIFARE_LoginSector(BYTE Sector,BYTE Type,BYTE *pKey);

//Read a data block
bool WINAPI HYMIFARE_ReadDataBlock(BYTE Block);

//Write a data block
bool WINAPI HYMIFARE_WriteDataBlock(BYTE Block,BYTE *pData);

//Read a value block
bool WINAPI HYMIFARE_ReadValueBlock(BYTE Block);

//Write a value block
bool WINAPI HYMIFARE_WriteValueBlock(BYTE Block,BYTE *pValue);

//Write master key
bool WINAPI HYMIFARE_WriteMasterKey(BYTE Block,BYTE *pKey);

//Increment value
bool WINAPI HYMIFARE_IncrementValue(BYTE Block,BYTE *pValue);

//Decrement value
bool WINAPI HYMIFARE_DecrementValue(BYTE Block,BYTE *pValue);

//Copy value
bool WINAPI HYMIFARE_CopyValue(BYTE Source,BYTE Destination);

//Reset
bool WINAPI HYMIFARE_Reset(void);

//Halt
bool WINAPI HYMIFARE_Halt(void);

//Continuous Read
bool WINAPI HYMIFARE_ContinuousRead(BYTE Block);

//Get ATS
bool WINAPI HYMIFARE_GetATS(void);

//Deselect
bool WINAPI HYMIFARE_Deselect(void);

//Exchange APDU
bool WINAPI HYMIFARE_ExchangeAPDU(BYTE *pData,int iLen);

//Smart card power up
bool WINAPI HYMIFARE_SmartCardPowerUp(int SAMID);

//Smart card power down
bool WINAPI HYMIFARE_SmartCardPowerDown(int SAMID);

//Smart Card Exchange APDU
bool WINAPI HYMIFARE_SmartCardExchangeAPDU(int SAMID,BYTE *pData,int iLen);

//IO Output
//Value: 0xFE -- Red,0xFD -- Green,0xFC -- Red & Green
bool WINAPI HYMIFARE_IOOutput(BYTE Mask,BYTE Value);

//Enter ISP
bool WINAPI HYMIFARE_EnterISP(void);

//Erase chip
bool WINAPI HYMIFARE_ChipErase(void);

//Programmer
bool WINAPI HYMIFARE_ByteProgram(int Addr,BYTE *DataBuf,int DataLen );

//Erase page
bool WINAPI HYMIFARE_PageErase(BYTE page );

//Protect
bool WINAPI HYMIFARE_ChipProtect(void);

//Verify
bool WINAPI HYMIFARE_ByteVerify(int Addr,BYTE *DataBuf,int DataLen );

bool WINAPI HY_ChangeBaudRate(BYTE BaudNum);
bool WINAPI HY_MIFARE_RequestMifareCard(BYTE *ATQA);
bool WINAPI HY_MIFARE_AutoLogin(BYTE Sector,BYTE Type,BYTE *Key);
bool WINAPI HY_MIFARE_LoginWithKeyStored(BYTE Sector,BYTE Type,BYTE KeyNum);
bool WINAPI HY_MIFARE_StoreKey(BYTE KeyNum,BYTE *Key);

#ifdef __cplusplus
}
#endif

#endif
